<script setup>
import { Head, Link, useForm } from '@inertiajs/inertia-vue3';
import Welcome from '@/Jetstream/Welcome.vue';
import JetButton from '@/Jetstream/Button.vue';
import JetModal from '@/Jetstream/Modal.vue';
import DK_Button from '@/components/dk_Button.vue';
import DK_Input from '@/components/dk_Input.vue';

let AppLayout;

if (window.location.origin.indexOf('localhost:8000') !== -1 || window.location.origin.indexOf('water.baltoro.app') !== -1) {
    AppLayout = require('@/Layouts/AppLayoutWater.vue').default;
} else {
    AppLayout = require('@/Layouts/AppLayoutCity.vue').default;
}

</script>

<style scoped>

</style>

<template>
    <AppLayout title="User Profile">
        <loader-component></loader-component>
        <div style="height: calc(100vh - 4.75rem);" v-if="this.screen_width >= 768"
            class="bg-darkblue-background px-8 pb-8 pt-5 z-0 cursor-default flex flex-col justify-center">

            <div class="w-full flex justify-end">                                    
                <DK_Button color="blue" :fixedSize="true" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                    {{ this.$t("general.Back") }}
                </DK_Button>
            </div>

            <div class="h-full flex flex-col justify-start align-center px-64 2xl:px-96">

                <p class="text-white-snow font-light text-2xl pb-4 pl-1">{{ this.$t("general.Edit User") }} </p>
        
                <div class="grid grid-cols-2 gap-x-8 px-8 py-4 gap-y-4 font-light text-gray-light text-center baltoro-container h-fit">
                    <div class="col-span-1">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "User") }}</p>
                        <DK_Input id="id_user_username" type="text" :placeholder="this.user_info[0].user" :border="true" textPosition="center" width="full"/>
                    </div>

                    <div class="col-span-1">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Name") }}</p>
                        <DK_Input id="id_user_name" type="text" :placeholder="this.user_info[0].name" :border="true" textPosition="center" width="full"/>
                    </div>

                    <div class="col-span-2">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Email") }}</p>
                        <DK_Input id="id_user_email" type="email" :placeholder="this.user_info[0].email" :border="true" textPosition="center" width="full"/>
                    </div>

                    <div class="col-span-1">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Password") }}</p>
                        <DK_Input id="id_user_password" type="password" :border="true" textPosition="center" width="full"/>
                    </div>

                    <div class="col-span-1">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Repeat password") }}</p>
                        <DK_Input id="id_user_repeat_password" type="password" :border="true" textPosition="center" width="full"/>
                    </div>

                    <div class="col-span-1">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Timezone") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_user_timezone" name="timezone"
                            v-model="user_timezone">
                            <option v-for="timezone in timezones" :key="timezone" class="bg-darkblue-opa-container"
                                :value="timezone">{{ timezone }}</option>
                        </select>
                    </div>

                    <div class="col-span-1">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Language") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_user_language" name="language"
                            v-model="user_languaje">
                            <option v-for="language in languages" :key="language" class="bg-darkblue-opa-container"
                                :value="language">{{ language }}</option>
                        </select>
                    </div>

                    <div class="flex justify-end col-span-2 gap-4 mt-4 pr-0.5">

                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveEditUser()">
                            {{ this.$t("general.Update") }}
                        </DK_Button>

                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelEditUser()">
                            {{ this.$t("general.Clear") }}
                        </DK_Button>

                    </div>
                </div>
            </div>
        </div>
        <div style="height: calc(100vh - 4.75rem);" v-else
            class="bg-darkblue-background px-3 py-2 z-0 cursor-default flex flex-col justify-start overflow-y-auto">

            <div class="w-full flex flex-col justify-center items-start pb-1 gap-2">

                <div class="w-full flex flex-row justify-between items-center h-[3.25rem]">
                    <div class="w-full flex flex-col justify-start">
                        <div class="flex flex-row justify-start">
                            <p class="text-white-snow font-light text-2xl text-left">{{ this.$t('general.Edit User') }}</p>
                        </div>
                    </div>
                    <div class="flex justify-end gap-2">
                        <div class="flex items-center justify-center">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                <button type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center">
                                    <i class="fa-solid fa-arrow-left" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                        </div>
                    </div>
                </div>  

                <div class="grid grid-cols-2 gap-x-8 p-4 gap-y-4 font-light text-gray-light text-center baltoro-container h-fit w-full">
                    <div class="col-span-2">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "User") }}</p>
                        <DK_Input id="id_user_username" type="text" :placeholder="this.user_info[0].user" :border="true" textPosition="center" width="full"/>
                    </div>

                    <div class="col-span-2">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Name") }}</p>
                        <DK_Input id="id_user_name" type="text" :placeholder="this.user_info[0].name" :border="true" textPosition="center" width="full"/>
                    </div>

                    <div class="col-span-2">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Email") }}</p>
                        <DK_Input id="id_user_email" type="email" :placeholder="this.user_info[0].email" :border="true" textPosition="center" width="full"/>
                    </div>

                    <div class="col-span-2">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Password") }}</p>
                        <DK_Input id="id_user_password" type="password" :border="true" textPosition="center" width="full"/>
                    </div>

                    <div class="col-span-2">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Repeat password") }}</p>
                        <DK_Input id="id_user_repeat_password" type="password" :border="true" textPosition="center" width="full"/>
                    </div>

                    <div class="col-span-2">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Timezone") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_user_timezone" name="timezone"
                            v-model="user_timezone">
                            <option v-for="timezone in timezones" :key="timezone" class="bg-darkblue-opa-container"
                                :value="timezone">{{ timezone }}</option>
                        </select>
                    </div>

                    <div class="col-span-2">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Language") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_user_language" name="language"
                            v-model="user_languaje">
                            <option v-for="language in languages" :key="language" class="bg-darkblue-opa-container"
                                :value="language">{{ language }}</option>
                        </select>
                    </div>

                    <div class="flex justify-end col-span-2 gap-4 mt-4 pr-0.5">

                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveEditUser()">
                            {{ this.$t("general.Update") }}
                        </DK_Button>

                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelEditUser()">
                            {{ this.$t("general.Clear") }}
                        </DK_Button>

                    </div>
                </div>
            </div>  
        </div>
    </AppLayout>
</template>

<script>
export default {

    props: ['groups', 'user_info', 'timezones', 'user'],

    data() {
        return {
            Back: localStorage.getItem('Back'),
            user_timezone: this.user_info[0].timezone,
            user_languaje: null, 
            languages: ["English", "Spanish", "Chinese"],
            screen_width: 0,
        }
    },

    beforeCreate: function () {
        this.$i18n.locale = this.user.language
    },    

    beforeMount() {
        this.screen_width = window.screen.width;
    },

    mounted() {      

        switch (this.user_info[0].language) {
            case 'en': this.user_languaje = 'English'; break;
            case 'es': this.user_languaje = 'Spanish'; break;
            case 'ch': this.user_languaje = 'Chinese'; break;
            default: this.user_languaje = 'English';
        }

        window.emitter.emit('changeLoaderStatus', false, 'orbit');
    },

    methods: {

        CancelEditUser(){

            document.getElementById('id_user_username').value = ''
            document.getElementById('id_user_name').value = ''
            document.getElementById('id_user_email').value = ''

            document.getElementById('id_user_password').value = ''
            document.getElementById('id_user_repeat_password').value = ''

            switch (this.user_info[0].language) {
                case 'en': this.user_languaje = 'English'; break;
                case 'es': this.user_languaje = 'Spanish'; break;
                case 'ch': this.user_languaje = 'Chinese'; break;
                default: this.user_languaje = 'English';
            }

            this.user_timezone = this.user_info[0].timezone;
        },

        SaveEditUser() {

            if(document.getElementById('id_user_password').value == '' && document.getElementById('id_user_repeat_password').value == ''){

                let user_username = (document.getElementById('id_user_username').value != '' ? document.getElementById('id_user_username').value : this.user_info[0].user)
                let user_name = (document.getElementById('id_user_name').value != '' ? document.getElementById('id_user_name').value : this.user_info[0].name)
                let user_email = (document.getElementById('id_user_email').value != '' ? document.getElementById('id_user_email').value : this.user_info[0].email)

                let user_languaje;

                switch (this.user_languaje) {
                    case 'English': user_languaje = 'en'; break;
                    case 'Spanish': user_languaje = 'es'; break;
                    case 'Chinese': user_languaje = 'ch'; break;
                    default: user_languaje = 'es';
                }

                let user_timezone = this.user_timezone

                const data = {
                    "user": user_username,
                    "name": user_name,
                    "email": user_email,
                    "password": null,
                    "confirm_password": null,
                    "idgroup_home": null,
                    "timezone": user_timezone,
                    "language": user_languaje,
                    "admin": null,
                    "updated_at": new Date().toISOString(),
                };

                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'put',
                    url: window.location.origin + '/api/user/edit/' + this.user.id + '/' + this.user.id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                    data: data
                })
                    .then((response) => {

                        Object.keys(data).forEach( (key, index) => {
                            if(data[key] != this.user_info[0][key] && data[key] != '' && data[key] != undefined && data[key] != null){
                                this.user_info[0][key] = data[key];
                            }
                        }) 

                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                    })
                    .catch((error) => {
                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                        if(error.response && error.response.status && error.response.status == 429){
                        window.alert( this.$t('text.Api attempts'));
                        }else{
                        return "Failed!", error;
                        }
                    });

            } else if( 
                this.CheckPasswordPolicies(document.getElementById('id_user_password').value, document.getElementById('id_user_repeat_password').value)
            ){

                let user_username = (document.getElementById('id_user_username').value != '' ? document.getElementById('id_user_username').value : this.user_info[0].user)
                let user_name = (document.getElementById('id_user_name').value != '' ? document.getElementById('id_user_name').value : this.user_info[0].name)
                let user_email = (document.getElementById('id_user_email').value != '' ? document.getElementById('id_user_email').value : this.user_info[0].email)

                let user_password = (document.getElementById('id_user_password').value != '' ? document.getElementById('id_user_password').value : this.user_info[0].name)
                let user_repeat_password = (document.getElementById('id_user_repeat_password').value != '' ? document.getElementById('id_user_repeat_password').value : this.user_info[0].email)

                let user_languaje;

                switch (this.user_languaje) {
                    case 'English': user_languaje = 'en'; break;
                    case 'Spanish': user_languaje = 'es'; break;
                    case 'Chinese': user_languaje = 'ch'; break;
                    default: user_languaje = 'es';
                }

                let user_timezone = this.user_timezone

                const data = {
                    "user": user_username,
                    "name": user_name,
                    "email": user_email,
                    "password": user_password,
                    "confirm_password": user_repeat_password,
                    "idgroup_home": null,
                    "timezone": user_timezone,
                    "language": user_languaje,
                    "admin": null,
                    "updated_at": new Date().toISOString(),
                };

                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'put',
                    url: window.location.origin + '/api/user/edit/' + this.user.id + '/' + this.user.id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                    data: data
                })
                    .then((response) => {

                        Object.keys(data).forEach( (key, index) => {
                            if(data[key] != this.user_info[0][key] && data[key] != '' && data[key] != undefined && data[key] != null){
                                this.user_info[0][key] = data[key];
                            }
                        }) 

                        window.emitter.emit('changeLoaderStatus', false, 'orbit')


                    })
                    .catch((error) => {
                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                        if(error.response && error.response.status && error.response.status == 429){
                        window.alert( this.$t('text.Api attempts'));
                        }else{
                        return "Failed!", error;
                        }

                    });
            } else if(
                !(document.getElementById('id_user_password').value === document.getElementById('id_user_repeat_password').value)
            ) {

                window.emitter.emit(
                    'AppLayout_alert', 
                    true, 
                    this.$t('text.Passwords match'), 
                    '', 
                    '18rem'
                )
            } else {

                window.emitter.emit(
                        'AppLayout_alert', 
                        true, 
                        this.$t('text.Passwords Policies Title'), 
                        this.$t('text.PasswordsPolicies'), 
                        '24rem'
                    )
            }
        },

        CheckPasswordPolicies(password1, password2) {

            const conditions = [
                /[a-z]/,
                /[A-Z]/,
                /\d/,
                /[@$!%*?&]/,
                /^.{8,}$/ 
            ];

            if(password2 && (password1 === password2)){                        
                return conditions.every(condition => condition.test(password1));
            }else{
                return false;
            }
        },
    },

}    
</script>
